<?php

class appKlikochronFrontendComponents extends sfComponents {

    public function executeShow() {
        $config = stConfig::getInstance('appKlikochronPlugin');

        if ($config->get('enabled')) {
            $this->config = $config;

            $module = $this->getModuleName();
            $action = $this->getActionName();
            
            if ($module != 'stOrder' || !in_array($action, array('confirm', 'summary')))
                return sfView::NONE;

            $this->partnerId = $config->get('partner_id');
            $this->shopId = $config->get('shop_id');
            $this->countryCode = '';

            $this->action = null; // 0 - confirm, 1 - summary

            if ($module == 'stOrder' && $action == 'confirm') {
                $this->action = 0;

                $billingData = $this->getRequestParameter('user_data_billing');

                $country = CountriesPeer::retrieveByPK($billingData['country']);
                if (is_object($country))
                    $this->countryCode = strtolower($country->getIsoA2());

                $products = array();
                foreach (stBasket::getInstance($this->getUser())->getItems() as $item) {

                    $categories = array();

                    $c = new Criteria();
                    $c->add(ProductHasCategoryPeer::PRODUCT_ID, $item->getProductId());
                    $c->addDescendingOrderByColumn(ProductHasCategoryPeer::IS_DEFAULT);
                    $categoriesList = ProductHasCategoryPeer::doSelectJoinCategory($c);

                    foreach ($categoriesList as $chp)
                        if (is_object($chp->getCategory()))
                            $categories[] = array((int) $chp->getCategory()->getId() => $chp->getCategory()->getName());

                    $currency = $item->getCurrency();

                    $products[] = array('id' => $item->getProductId(),
                                        'name' => $item->getName(),
                                        'categories' => $categories,
                                        'price' => $item->getPriceBrutto(),
                                        'currency' => strtolower($currency['code']),
                                        'sku' => $item->getCode(),
                                        'qty' => $item->getQuantity()
                                        );
                }

                $this->products = json_encode($products);
            }

            if ($module == 'stOrder' && $action == 'summary') {
                $this->action = 1;

                $this->orderId = '';
                $this->customer = '';

                if (stPaymentType::hasOrderInSummary()) {
                    $order = stPaymentType::getOrderInSummary();

                    if (is_object($order) && is_object($order->getOrderUserDataBilling())) {
                        $user = $order->getOrderUserDataBilling();
                        $this->countryCode = strtolower($user->getCountries()->getIsoA2());

                        $this->orderId = $order->getNumber();

                        $this->customer = json_encode(array('firstname' => $user->getName(),
                                                            'lastname' => $user->getSurname(),
                                                            'email' => $order->getOptClientEmail(),
                                                            'phone' => $user->getPhone(),
                                                            'street' => $user->getStreet(),
                                                            'street_number' => ($user->getHouse() != '-' ? $user->getHouse() : '').($user->getFlat() ? ' '.$user->getFlat() : ''),
                                                            'zip' => $user->getCode(),
                                                            'city' => $user->getTown(),
                                                            'country' => strtolower($user->getCountries()->getIsoA2()),
                                                        ));
                    }
                }
            }
        } else
            return sfView::NONE;        
    }
}